cnc_rgb = {
    'anyuzi': '#5c2223',
    'mudanfenhong': '#eea2a4',
    'lizi': '#2b1216',
    'xiangyehong': '#f07c82',
    'putaojiangzi': '#5a1216',
    'yanhong': '#82111f',
    'yuhong': '#c04851',
    'chahuahong': '#ee3f4d',
    'gaolianghong': '#c02c38',
    'manjianghong': '#a7535a',
    'shubihong': '#e3b4b8',
    'hehuanhong': '#f0a1a8',
    'chunmeihong': '#f1939c',
    'xiancaihong': '#a61b29',
    'meihong': '#c45a65',
    'eguanhong': '#d11a2d',
    'fengyehong': '#c21f30',
    'tangchangpuhong': '#de1c31',
    'zaohong': '#7c1823',
    'zhuganzi': '#541e24',
    'putaozi': '#4c1f24',
    'anziyuanhong': '#82202b',
    'caomolihong': '#ef475d',
    'jiangzi': '#4d1018',
    'shanchahong': '#ed556a',
    'xinhui': '#7a7374',
    'haitanghong': '#f03752',
    'jifenhong': '#e6d2d5',
    'shiruihong': '#f0c9cf',
    'danshuhong': '#ed4845',
    'shizhuhong': '#ee4863',
    'danqianhong': '#e77c8e',
    'jinyuzi': '#500a16',
    'shanlidouhong': '#c27c88',
    'shubeihui': '#73575c',
    'danruixianghong': '#ee4866',
    'ganzhezi': '#621624',
    'yuejihong': '#ce5777',
    'jianjingyuhong': '#cc163a',
    'shuihong': '#f1c4cd',
    'jianghong': '#eeb8c3',
    'luhui': '#856d72',
    'qiepizi': '#2d0c13',
    'cangyinghui': '#36282b',
    'jinkuihong': '#bf3553',
    'fentuanhuahong': '#ec9bad',
    'shizhuzi': '#63071c',
    'luanshizi': '#30161c',
    'jinghong': '#eea6b7',
    'zhilanzi': '#e9ccd3',
    'shaoyaogenghong': '#eba0b3',
    'muyunhui': '#4f383e',
    'jiangdouhong': '#ed9db2',
    'baochunhong': '#ec8aa4',
    'danjianghong': '#ec7696',
    'fengxianhuahong': '#ea7293',
    'xiaguanghong': '#ef82a0',
    'xidanhong': '#ec2c64',
    'jiazhutaohong': '#eb507e',
    'songyemudanhong': '#eb3c70',
    'lianbanhong': '#ea517f',
    'baijihong': '#de7897',
    'yinhonghui': '#b598a1',
    'wenpohong': '#ed2f6a',
    'cujiangcaohong': '#c5708b',
    'huoezi': '#33141e',
    'yaoguanzi': '#621d34',
    'pinhong': '#ef3473',
    'moshizi': '#382129',
    'mozi': '#310f1b',
    'tanzi': '#381924',
    'chuhehong': '#e16c96',
    'caitouzi': '#951c48',
    'putaojiuhong': '#62102e',
    'danqingzi': '#e0c8d1',
    'bogenhong': '#d13c74',
    'haixiangzi': '#4b1e2f',
    'tuyanhong': '#ec4e8a',
    'nenlinghong': '#de3f7c',
    'yangcongzi': '#a8456b',
    'diaozhonghuahong': '#ce5e8a',
    'ganzi': '#461629',
    'zijinghong': '#ee2c79',
    'biandouhuahong': '#ef498b',
    'mabiancaozi': '#ede3e7',
    'canghuahong': '#ec2d7a',
    'banjiuhui': '#482936',
    'gutongzi': '#440e25',
    'danzihong': '#d2568c',
    'dingxiangdanzi': '#e9d7df',
    'meiguihong': '#d2357d',
    'gudinghui': '#36292f',
    'lingmenghong': '#d276a3',
    'yingcaozi': '#c06f98',
    'longxuhong': '#cc5595',
    'dianqishihong': '#c35691',
    'meiguizi': '#ba2f7b',
    'xiancaizi': '#9b1e64',
    'zihui': '#5d3f51',
    'longjingyuzi': '#4e2a40',
    'qinghakezi': '#bc84a8',
    'luolanzi': '#c08eaf',
    'biqizi': '#411c35',
    'doukouzi': '#ad6598',
    'biandouzi': '#a35c8f',
    'qianniuzi': '#681752',
    'zizi': '#894276',
    'gejinzi': '#7e2065',
    'qinglian': '#8b2671',
    'jiehuazi': '#983680',
    'fengxinzi': '#c8adc4',
    'shenqianniuzi': '#1c0d1a',
    'weizi': '#7e1671',
    'wumeizi': '#1e131d',
    'jiegengzi': '#813c85',
    'danqianniuzi': '#d1c2d3',
    'jianfengzi': '#3e3841',
    'xunzi': '#815c94',
    'jinzi': '#806d9e',
    'qianshibai': '#e2e1e4',
    'longkuizi': '#322f3b',
    'tengluozi': '#8076a3',
    'shayuhui': '#35333c',
    'anlongdanzi': '#22202e',
    'anlanzi': '#131124',
    'yeputaozi': '#302f4b',
    'yejuzi': '#525288',
    'shuiniuhui': '#2f2f35',
    'yuanshanzi': '#ccccd6',
    'luodianzi': '#74759b',
    'jingshizi': '#1f2040',
    'mantianxingzi': '#2e317c',
    'danlanzi': '#a7a8bd',
    'shangengzi': '#61649f',
    'niujiaohui': '#2d2e36',
    'yuweihui': '#5e616d',
    'waguanhui': '#47484c',
    'ganglan': '#0f1423',
    'yanhanlan': '#131824',
    'jingyuhui': '#475164',
    'qinghui': '#2b333e',
    'gelan': '#1c2938',
    'anlan': '#101f30',
    'gangqing': '#142334',
    'haitaolan': '#15559a',
    'feiyancaolan': '#0f59a4',
    'dianqing': '#1661ab',
    'ananlan': '#3170a7',
    'haijunlan': '#346c9c',
    'jingtailan': '#2775b6',
    'pinlan': '#2b73af',
    'niluolan': '#2474b5',
    'diechilan': '#4e7ca1',
    'huaqing': '#2376b7',
    'yanlan': '#144a74',
    'xinglan': '#93b5cf',
    'honglan': '#2177b8',
    'bolinlan': '#126bae',
    'qunqing': '#1772b4',
    'yunshuilan': '#baccd9',
    'yushandoulan': '#619ac3',
    'zhanjianhui': '#495c69',
    'qingshanlan': '#8fb2c9',
    'jinglan': '#5698c3',
    'tangcilan': '#11659a',
    'chaolan': '#2983bb',
    'tianlan': '#1677b3',
    'dalishihui': '#c4cbcf',
    'qianniuhualan': '#1177b0',
    'baoshilan': '#2486b9',
    'danlanhui': '#5e7987',
    'nenhui': '#74787a',
    'yinyubai': '#cdd1d3',
    'youlan': '#1781b5',
    'jianshilan': '#66a9c9',
    'yuantianlan': '#d0dfe6',
    'yunshanlan': '#2f90b9',
    'qiubolan': '#8abcd1',
    'jingtianlan': '#c3d7df',
    'yuanweilan': '#158bb8',
    'yunfengbai': '#d8e3e7',
    'xinghui': '#b2bbbe',
    'gulan': '#1a94bc',
    'biqing': '#5cb3cc',
    'canglan': '#134857',
    'shenhuilan': '#132c33',
    'huilan': '#21373d',
    'hushuilan': '#b0d5df',
    'haiqing': '#22a2c3',
    'huanghunhui': '#474b4c',
    'jiqing': '#63bbd0',
    'yuqinlan': '#126e82',
    'danfanlan': '#0f95b0',
    'jianniaolan': '#1491a8',
    'oulan': '#c7d2d4',
    'cuilan': '#1e9eb3',
    'qingtinglan': '#3b818c',
    'kongquelan': '#0eb0c9',
    'weilan': '#29b7cb',
    'pubulan': '#51c4d3',
    'shanlan': '#7cabb1',
    'dianzilan': '#10aec2',
    'wanbolan': '#648e93',
    'qingshuilan': '#93d5dc',
    'xiayunhui': '#617172',
    'haitianlan': '#c6e6e8',
    'xiakeqing': '#869d9d',
    'shilv': '#57c3c2',
    'qionghui': '#c4d7d6',
    'meidielv': '#12aa9c',
    'ehui': '#737c7b',
    'lanlv': '#12a182',
    'zhulv': '#1ba784',
    'yadinglv': '#428675',
    'yueyingbai': '#c0c4c3',
    'haiwanglv': '#248067',
    'shenhailv': '#1a3b32',
    'lvhui': '#314a43',
    'qingfanlv': '#2c9678',
    'canglv': '#223e36',
    'feiquanlv': '#497568',
    'mangconglv': '#141e1b',
    'wuzhilv': '#69a794',
    'tonglv': '#2bae85',
    'caoyuanyuanlv': '#9abeaf',
    'walv': '#45b787',
    'langhualv': '#92b3a5',
    'ganlanlv': '#5e5314',
    'fenlv': '#83cbac',
    'danlvhui': '#70887d',
    'maimiaolv': '#55bb8a',
    'cuilv': '#20a162',
    'conglv': '#40a070',
    'heyelv': '#1a6840',
    'danlv': '#61ac85',
    'tianyuanlv': '#68b88e',
    'yuzanlv': '#a4cab6',
    'chanlv': '#3c9566',
    'koushaolv': '#5dbe8a',
    'bohelv': '#207f4c',
    'yuebai': '#eef7f2',
    'danbaishilv': '#579572',
    'zhuhuanglv': '#b9dec9',
    'kongquelv': '#229453',
    'gongdianlv': '#20894d',
    'yunshanlv': '#15231b',
    'maolv': '#66c18c',
    'bingshanlan': '#a4aca7',
    'minghui': '#8a988e',
    'minglv': '#9eccab',
    'songshuanglv': '#83a78d',
    'baiqucailv': '#485b4d',
    'langyanhui': '#5d655f',
    'wasonglv': '#6e8b74',
    'hujishenglv': '#2b312c',
    'dancuilv': '#c6dfc8',
    'yusuilv': '#41b349',
    'xianlv': '#43b244',
    'youlv': '#253d24',
    'baoshilv': '#41ae3c',
    'jialingshuilv': '#add5a2',
    'tianluolv': '#5e665b',
    'shuilv': '#8cc269',
    'yingwulv': '#5bae23',
    'aibeilv': '#dfecd5',
    'ailv': '#cad3c3',
    'niehui': '#9fa39a',
    'ganlanshilv': '#b2cf87',
    'yalv': '#96c24e',
    'nenjulv': '#f0f5e5',
    'luweilv': '#b7d07a',
    'yaohuang': '#d0deaa',
    'enyoulv': '#373834',
    'pingguolv': '#bacf65',
    'haimeilv': '#e2e7bf',
    'ganlanhuanglv': '#bec936',
    'huaihuahuanglv': '#d2d97a',
    'diehuang': '#e2d849',
    'xiangyabai': '#fffef8',
    'xuebai': '#fffef9',
    'danhuilv': '#ad9e5f',
    'foshouhuang': '#fed71a',
    'rubai': '#f9f4dc',
    'xiangjiaohuang': '#e4bf11',
    'xinhelv': '#d2b116',
    'youcaihuahuang': '#fbda41',
    'qiukuihuang': '#eed045',
    'youhuang': '#fcb70a',
    'caohuang': '#d2b42c',
    'liuhuahuang': '#f2ce2b',
    'jianghuang': '#e2c027',
    'tanshuilv': '#645822',
    'jinguahuang': '#fcd217',
    'maiganhuang': '#f8df70',
    'haohuang': '#dfc243',
    'molihuang': '#f8df72',
    'tenghuang': '#ffd111',
    'mangguohuang': '#ddc871',
    'haishenhui': '#fffefa',
    'biluochunlv': '#867018',
    'tailv': '#887322',
    'ningmenghuang': '#fcd337',
    'caohuilv': '#8e804b',
    'xiangrikuihuang': '#fecc11',
    'suxinhuang': '#fccb16',
    'ruyahuang': '#ffc90c',
    'yuehui': '#b7ae8f',
    'kuishanhuang': '#f8d86a',
    'dadouhuang': '#fbcd31',
    'jinzhanhuang': '#fcc307',
    'juleibai': '#e9ddb6',
    'huanglianhuang': '#fcc515',
    'xingrenhuang': '#f7e8aa',
    'guhuang': '#e8b004',
    'muguahuang': '#f9c116',
    'danjianhuang': '#f9d770',
    'yalihuang': '#fbc82f',
    'yinbai': '#f1f0ed',
    'zonglvlv': '#5b4913',
    'yingwuguanhuang': '#f6c430',
    'kulv': '#b78d12',
    'qianlaohuang': '#f9bd10',
    'danmihuang': '#f9d367',
    'jiehuang': '#d9a40e',
    'zhizihuang': '#ebb10d',
    'anhaishuilv': '#584717',
    'miehuang': '#f7de98',
    'bangroubai': '#f9f1db',
    'chaomihuang': '#f4ce69',
    'hupohuang': '#feba07',
    'huilv': '#8a6913',
    'zongyelv': '#876818',
    'chenhui': '#b6a476',
    'xiangyahuang': '#f0d695',
    'jiaoqing': '#87723e',
    'douzhihuang': '#f8e8c1',
    'tuhuang': '#d6a01d',
    'xiangshuimeiguihuang': '#f7da94',
    'hupihuang': '#eaad1a',
    'jidanhuang': '#fbb612',
    'yinshuhui': '#b5aa90',
    'yudubai': '#f7f4ed',
    'chushuxinghuang': '#f8bc31',
    'shanjihuang': '#b78b26',
    'lianzibai': '#e5d3aa',
    'xiekehui': '#695e45',
    'shashihuang': '#e5b751',
    'gancaohuang': '#f3bf4c',
    'yanyuhui': '#685e48',
    'ezhanghuang': '#fbb929',
    'maiyatanghuang': '#f9d27d',
    'qiantuose': '#e2c17c',
    'bailingniaohui': '#b4a992',
    'laohuang': '#f6dead',
    'liroubai': '#f2e6ce',
    'danrouse': '#f8e0b0',
    'hetunhui': '#393733',
    'yililv': '#835e1d',
    'hanbaiyu': '#f8f4ed',
    'chengpihuang': '#fca104',
    'laiyanglihuang': '#815f25',
    'pipahuang': '#fca106',
    'jinyehuang': '#ffa60f',
    'canghuang': '#806332',
    'fenbai': '#fbf2e3',
    'danjucheng': '#fba414',
    'zhenzhuhui': '#e4dfd7',
    'guibeihuang': '#826b48',
    'qianhui': '#bbb5ac',
    'zhonghui': '#bbb5ac',
    'xionghuang': '#ff9900',
    'mihuang': '#fbb957',
    'fengfanhuang': '#dc9123',
    'guipidanzong': '#c09351',
    'jinyinghuang': '#f4a83a',
    'rouse': '#f7c173',
    'diaoyezong': '#e7a23f',
    'gutonglv': '#533c1b',
    'luoyingdanfen': '#f9e8d0',
    'ruanmuhuang': '#de9e44',
    'guarangfen': '#f9cb8b',
    'liuehuang': '#f9a633',
    'daimaohuang': '#daa45a',
    'jiaochalv': '#553b18',
    'xiekelv': '#513c20',
    'shanjihe': '#986524',
    'houmaohui': '#97846c',
    'lujiaozong': '#e3bd8d',
    'dansongyan': '#4d4030',
    'wanshoujuhuang': '#fb8b05',
    'dankehuang': '#f8c387',
    'xinghuang': '#f28e16',
    'ganlanhui': '#503e2a',
    'hehui': '#4a4035',
    'manaohui': '#cfccc9',
    'danyinhui': '#c1b2a3',
    'wahui': '#867e76',
    'yehui': '#847c74',
    'beiguahuang': '#fc8c23',
    'hehuabai': '#fbecde',
    'songshuhui': '#4f4032',
    'danmifen': '#fbeee2',
    'shenhui': '#81776e',
    'haiouhui': '#9a8878',
    'chahe': '#5d3d21',
    'tuose': '#66462a',
    'yinhui': '#918072',
    'lupihe': '#d99156',
    'binglangzong': '#c1651a',
    'xiaohui': '#d4c4b7',
    'danzhe': '#be7e4a',
    'gutonghe': '#5c3719',
    'jizong': '#de7622',
    'zuiguarou': '#db8540',
    'yanhui': '#80766e',
    'guiyuhong': '#f09c5a',
    'jucheng': '#f97d1c',
    'jinhuang': '#f26b1f',
    'meiguifen': '#f8b37f',
    'meirenjiaocheng': '#fa7e23',
    'mise': '#f9e9cd',
    'zhuwanghui': '#b7a091',
    'dankafei': '#945833',
    'hailuocheng': '#f0945d',
    'yanshizong': '#964d22',
    'mangguozong': '#954416',
    'taocihong': '#e16723',
    'boluohong': '#fc7930',
    'yujinhong': '#cf7543',
    'jinlianhuacheng': '#f86b1d',
    'huozhuanhong': '#cd6227',
    'chutaofenhong': '#f6dcce',
    'tiezong': '#d85916',
    'jieqiaodanfenhong': '#f7cfba',
    'xiekehong': '#f27635',
    'jintuo': '#e46828',
    'yanhanhong': '#fc6315',
    'dankekezong': '#b7511d',
    'chenxihong': '#ea8958',
    'yufenhong': '#e8b49a',
    'yeqiangweihong': '#fb9968',
    'ouhe': '#edc3ae',
    'changshihui': '#363433',
    'zhonghonghui': '#8b614d',
    'huonizong': '#aa6a4c',
    'ganhong': '#a6522c',
    'meijianghong': '#fa5d19',
    'dingxiangzong': '#71361d',
    'danmeiguihui': '#b89485',
    'guaranghong': '#f68c60',
    'dancanghuahong': '#f6ad8f',
    'sunpizong': '#732e12',
    'runhong': '#f7cdbc',
    'longjingyuhong': '#ef632b',
    'dantuhuang': '#8c4b31',
    'zhumuhui': '#64483d',
    'furonghong': '#f9723d',
    'luoxiahong': '#cf4813',
    'faluohong': '#ee8055',
    'caozhuhong': '#f8ebe6',
    'kafei': '#753117',
    'zhonghuituo': '#603d30',
    'yekezong': '#883a1e',
    'xiemaohong': '#b14b28',
    'dandousha': '#873d24',
    'dantaohong': '#f6cec1',
    'dantiehui': '#5b423a',
    'shibanhui': '#624941',
    'danlizong': '#673424',
    'yinzhu': '#f43e06',
    'caomeihong': '#ef6f48',
    'yangshuixianhong': '#f4c7ba',
    'zhuhong': '#ed5126',
    'liuhuahong': '#f34718',
    'shihong': '#f2481b',
    'kekezong': '#652b1c',
    'danyingsuhong': '#eea08c',
    'dahong': '#f04b22',
    'zhayezong': '#692a1b',
    'qingtinghong': '#f1441d',
    'xiangshuzong': '#773d31',
    'jiahong': '#eeaa9c',
    'taohong': '#f0ada0',
    'huoyanzong': '#863020',
    'dantengluozi': '#f2e7e5',
    'zheshi': '#862617',
    'tieshuihong': '#f5391c',
    'yanzhihong': '#f03f24',
    'jiguanghong': '#f33b1f',
    'honggonghong': '#f23e23',
    'luobohong': '#f13c22',
    'quhong': '#f05a46',
    'guqiaohong': '#f17666',
    'pingguohong': '#f15642',
    'guihong': '#f25a47',
    'fenhong': '#f2b9b2',
    'antuozong': '#592620',
    'xiyanghong': '#de2a18',
    'yingtaohong': '#ed3321',
    'shanhuhong': '#f04a3a',
    'huoshanzong': '#482522',
    'lizong': '#5c1e19',
    'hedinghong': '#d42517',
    'shehong': '#f19790',
    'exueshihong': '#ab372f',
    'jiangzong': '#5a1f1b',
    'yusaihong': '#ed3b2f',
    'lusuihui': '#bdaead',
    'lichunhong': '#eb261a',
    'fupenzihong': '#ac1f18',
    'haibaohui': '#483332',
    'dousha': '#481e1c',
    'liuzihong': '#f1908c',
    'qiuhaitanghong': '#ec2b24',
    'wuhuaguohong': '#efafad',
    'danfei': '#f2cac9',
    'meiguihui': '#4b2e2b',
    'goushuhong': '#ed3333',
    'diaozi': '#5d3131',
}



import pandas as pd
import matplotlib.pyplot as plt
from .colors import cnc_rgb

# TODO: to complete
trans_dict = {
    'red': 'hong',
    'grey': 'hui',
    'gray': 'hui',
    'purple': 'zi',
    'yellow': 'huang',
    'cyan': 'qing',
    'green': 'lv',
    'blue': 'lan',
    'white': 'bai',
    'brown': 'zong',
    'black': 'hei',
}


def show_color(clr_name=None):
    print(f'Reference: http://zhongguose.com/#{clr_name}')
    fig, ax = plt.subplots()
    ax.axis('off')
    ax.set_title(f'Name: {clr_name}; RGB: {cnc_rgb[clr_name]}')
    ax.scatter(1, 1, c=cnc_rgb[clr_name], s=1e4, marker='s')

def show(clr_name=None, ncol=3, fs=15, figsize=[10, 20]):
    print(f'Reference: http://zhongguose.com')
    fig, ax = plt.subplots(figsize=figsize)
    ax.axis('off')
    i_row, i_col = 0, 0
    if clr_name is None:
        clr_dict = cnc_rgb
    else:
        clr_name = trans_dict[clr_name] if clr_name in trans_dict else clr_name
        clr_dict = {k: v for k, v in cnc_rgb.items() if clr_name in k}

    for k, v in clr_dict.items():
        ax.scatter(i_col, i_row, c=v, s=1e2, marker='s', edgecolor='k')
        ax.text(i_col+0.1, i_row, k, color='k', fontsize=fs, verticalalignment='center')
        i_col -= 1
        if i_col == -ncol:
            i_row -= 1
            i_col = 0

def to_df():
    df = pd.DataFrame(cnc_rgb.items(), columns=['name', 'rgb'])
    print(f'Reference: http://zhongguose.com')
    return df







from setuptools import setup, find_packages

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name='cncolors',  # required
    version='0.1.0',
    description='cncolors: the library for Chinese colors',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    author='Feng Zhu',
    author_email='fzhu2e@outlook.com',
    url='https://github.com/fzhu2e/cnc',
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    zip_safe=False,
    keywords='python, colors',
    classifiers=[
        'Natural Language :: English',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    install_requires=[
        'pandas',
    ],
)
